#!/bin/bash
# packager           : jp.guillemin@free.fr
# source location    : http://www.nongnu.org/streamtuner/


softname='streamtuner'
softversion='0.99.99'
packageversion='64.2'

arch='i486'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="${buildir}/$softname-$softversion.tar.gz"
src="${buildir}/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="/tmp/$package"

# prepare the build result directory
rm -rf ${dest}
mkdir -p ${dest}/install
mkdir -p ${dest}/${prefix}/bin
mkdir -p ${dest}${prefix}/doc/$softname-$softversion
mkdir -p ${dest}${prefix}/share/applications
mkdir -p ${dest}${prefix}/share/icons/hicolor/scalable/apps/
mkdir -p ${dest}${prefix}/src/$softname-$softversion

# Slack-desc
cat <<EOF > ${dest}/install/slack-desc
$softname: A gtk2+ Stream directory browser
$softname:
$softname: Streamtuner is a stream directory browser. Through the use of a
$softname: plugin system, it offers an intuitive GTK+ 2.0 interface to 
$softname: Internet radio directories such as SHOUTcast and Live365.
$softname:
$softname:
$softname:
$softname: 
$softname:
$softname:
EOF

# extract the source code

cd ${buildir}
rm -rf ${src}
tar -xvf ${srcpkg}
cd ${src}

# configure package for compilation and install package to the target directory

# patch -p0 < ${buildir}/streamtuner-0.99.99-live365.diff
patch -p0 < ${buildir}/streamtuner-0.99.99-pygtk-2.6.diff
patch -p1 < ${buildir}/streamtuner-0.99.99-zenwalk.diff
patch -p0 < ${buildir}/streamtuner-0.99.99-shoutcast.diff
sed -i 's@http://www.shoutcast.com/@http://classic.shoutcast.com/@' src/plugins/shoutcast/shoutcast.c

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=${prefix} \
      --sysconfdir=/etc \
      --disable-local \
      --disable-live365 \
      --program-prefix="" \
      --program-suffix="" \
      --build=$arch-slackware-linux


# make package
#
    make -j2
    make install DESTDIR=${dest}

# add 'default' files
    cp -a \
      AUTHORS COPYING README INSTALL TODO NEWS \
      ${dest}${prefix}/doc/$softname-$softversion
      
# Strip Executables
( cd ${dest}
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress Man Pages
( cd ${dest}${prefix}/man
  find . -name "*.?" | xargs gzip -9
)

cat << "EOL" > ${dest}${prefix}/bin/streamtuner-launch
#!/bin/bash
if [ "$1" ] ; then 
	killall -u $USER -9 streamtuner
	streamtuner "$1" &
else
	ps x | grep -q ":[0-9]* streamtuner" || streamtuner &
fi
EOL
chmod 755 ${dest}${prefix}/bin/streamtuner-launch

# make the .desktop file
cat << "EOF" > ${dest}${prefix}/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Type=Application
Name=Streamtuner
GenericName=Stream Directory Browser
GenericName[de]=Streamverzeichnis durchsuchen
GenericName[fr]=Navigateur de Répertoire de Stations
GenericName[ja]=ストリーム ディレクトリ ブラウザ
Comment=Browse Internet stream directories
Comment[de]=Internet Streamverzeichnisse durchsuchen
Comment[fr]=Parcours les répertoires de stations sur Internet
Comment[ja]=インターネットストリーム ディレクトリを調べる
Icon=streamtuner
TryExec=streamtuner
Exec=streamtuner-launch
Terminal=false
Categories=Application;AudioVideo;GTK;Tuner;
StartupNotify=true
EOF

# Icons cooking
cd ${buildir}
rm -rf ${dest}${prefix}/share/streamtuner/ui
rm -f ${dest}${prefix}/share/pixmaps/$softname.png
tar -zxvf streamtuner-tango.tar.gz -C ${dest}${prefix}/share/streamtuner
cp -f ${dest}${prefix}/share/streamtuner/ui/$softname.svg ${dest}${prefix}/share/icons/hicolor/scalable/apps/$softname.svg

# put the ZenWalk build and patches in the right directory
cd ${buildir}
cp -a \
   build-$softname.sh streamtuner-0.99.99-live365.diff streamtuner-0.99.99-pygtk-2.6.diff streamtuner-0.99.99-zenwalk.diff \
   ${dest}/${prefix}/src/$softname-$softversion

# set target permissions
chown -R root:root ${dest}

cd ${dest}
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd ${dest}
makepkg -l y -c n ${dest}.txz

# cleanup
rm -rf ${dest}
rm -rf ${src}

